@@ -8,7 +8,7 @@ class api:
     docstring
     """
 
-    def __init__(self, name, server, hostAddr="0.0.0.0:80"):
+    def __init__(self, name, server):
         self.urls = {}
         self.server = server
         self.name = name
